/* Generated by Nim Compiler v1.6.6 */
#define NIM_INTBITS 64
#define NIM_EmulateOverflowChecks

#include "nimbase.h"
#include <stdio.h>
#undef LANGUAGE_C
#undef MIPSEB
#undef MIPSEL
#undef PPC
#undef R3000
#undef R4000
#undef i386
#undef linux
#undef mips
#undef near
#undef far
#undef powerpc
#undef unix
#define nimfr_(x, y)
#define nimln_(x, y)
typedef struct tyObject_PyMethodDef__9aWi1PsmvCuTKIYDHHnhfcw tyObject_PyMethodDef__9aWi1PsmvCuTKIYDHHnhfcw;
typedef struct TNimType TNimType;
typedef struct TNimNode TNimNode;
typedef struct tyObject_PyTypeObject3Obj__cRsC9bGvH9bX6A9aVx8UB6I5g tyObject_PyTypeObject3Obj__cRsC9bGvH9bX6A9aVx8UB6I5g;
typedef struct tyObject_PyMemberDef__WC29aEeHi2Pdy9c4AkllcBTg tyObject_PyMemberDef__WC29aEeHi2Pdy9c4AkllcBTg;
typedef struct tyObject_PyObjectObj__aD5pkFWInXrZXinZ42cDEg tyObject_PyObjectObj__aD5pkFWInXrZXinZ42cDEg;
typedef struct tyObject_PyObjectVarHeadObj__5fAkl5kIcYJNl6VvYzZdMw tyObject_PyObjectVarHeadObj__5fAkl5kIcYJNl6VvYzZdMw;
typedef N_CDECL_PTR(void*, tyProc__uQWqJp3WAx8fOY1h9aCwjIg) (void* s, void* a, void* k);
struct tyObject_PyMethodDef__9aWi1PsmvCuTKIYDHHnhfcw {
NCSTRING ml_name;
tyProc__uQWqJp3WAx8fOY1h9aCwjIg ml_meth;
int ml_flags;
NCSTRING ml_doc;
};
typedef NU8 tyEnum_TNimKind__jIBKr1ejBgsfM33Kxw4j7A;
typedef NU8 tySet_tyEnum_TNimTypeFlag__v8QUszD1sWlSIWZz7mC4bQ;
typedef N_NIMCALL_PTR(void, tyProc__ojoeKfW4VYIm36I9cpDTQIg) (void* p, NI op);
typedef N_NIMCALL_PTR(void*, tyProc__WSm2xU5ARYv9aAR4l0z9c9auQ) (void* p);
struct TNimType {
NI size;
NI align;
tyEnum_TNimKind__jIBKr1ejBgsfM33Kxw4j7A kind;
tySet_tyEnum_TNimTypeFlag__v8QUszD1sWlSIWZz7mC4bQ flags;
TNimType* base;
TNimNode* node;
void* finalizer;
tyProc__ojoeKfW4VYIm36I9cpDTQIg marker;
tyProc__WSm2xU5ARYv9aAR4l0z9c9auQ deepcopy;
};
typedef NU8 tyEnum_TNimNodeKind__unfNsxrcATrufDZmpBq4HQ;
struct TNimNode {
tyEnum_TNimNodeKind__unfNsxrcATrufDZmpBq4HQ kind;
NI offset;
TNimType* typ;
NCSTRING name;
NI len;
TNimNode** sons;
};
typedef N_CDECL_PTR(void*, tyProc__eYT4U6bGFqFBUxk9b15mfOA) (tyObject_PyTypeObject3Obj__cRsC9bGvH9bX6A9aVx8UB6I5g* typ, void* a, void* b);
struct tyObject_PyMemberDef__WC29aEeHi2Pdy9c4AkllcBTg {
NCSTRING name;
int typ;
NI offset;
int flags;
NCSTRING doc;
};
struct tyObject_PyObjectObj__aD5pkFWInXrZXinZ42cDEg {
NI ob_refcnt;
void* ob_type;
};
struct tyObject_PyObjectVarHeadObj__5fAkl5kIcYJNl6VvYzZdMw {
  tyObject_PyObjectObj__aD5pkFWInXrZXinZ42cDEg Sup;
NI ob_size;
};
typedef N_CDECL_PTR(void, tyProc__32w2ZypAyMWuajvi2Jt79cg) (void* o);
typedef N_CDECL_PTR(int, tyProc__rNiGphbUW4RHd2WIj64deg) (void* o, FILE* f, int c);
typedef N_CDECL_PTR(void*, tyProc__YezmFzxOOyM9cb11Eoq1Elg) (void* o, NCSTRING a);
typedef N_CDECL_PTR(int, tyProc__T08W9bgbY4bOv2q64h6irpw) (void* o, NCSTRING a, void* at);
typedef N_CDECL_PTR(void*, tyProc__jvPpjMAkI9bwM1B9apOphnlA) (void* o);
typedef N_CDECL_PTR(void*, tyProc__VQ1ysQk017myXMGb79cPTVw) (void* o, void* a);
typedef N_CDECL_PTR(int, tyProc__7LMjBc4zOHVIsNdulNv7QQ) (void* o, void* a, void* at);
typedef N_CDECL_PTR(void*, tyProc__k4RBH32nrpDxtGF9acg45zw) (void* a, void* b, int c);
typedef N_CDECL_PTR(void*, tyProc__Cj3MN9a7OA9a51xOtsYjEwBg) (tyObject_PyTypeObject3Obj__cRsC9bGvH9bX6A9aVx8UB6I5g* typ, NI sz);
typedef N_CDECL_PTR(void*, tyProc__3hYcL7bVv9cte9aw9aoXtthhA) (void* c, void** args, size_t nargs, void* kwnames);
struct tyObject_PyTypeObject3Obj__cRsC9bGvH9bX6A9aVx8UB6I5g {
  tyObject_PyObjectVarHeadObj__5fAkl5kIcYJNl6VvYzZdMw Sup;
NCSTRING tp_name;
NI tp_basicsize;
NI tp_itemsize;
tyProc__32w2ZypAyMWuajvi2Jt79cg tp_dealloc;
tyProc__rNiGphbUW4RHd2WIj64deg tp_print;
tyProc__YezmFzxOOyM9cb11Eoq1Elg tp_getattr;
tyProc__T08W9bgbY4bOv2q64h6irpw tp_setattr;
void* tp_as_async;
tyProc__jvPpjMAkI9bwM1B9apOphnlA tp_repr;
void* tp_as_number;
void* tp_as_sequence;
void* tp_as_mapping;
void* tp_hash;
void* tp_call;
tyProc__jvPpjMAkI9bwM1B9apOphnlA tp_str;
tyProc__VQ1ysQk017myXMGb79cPTVw tp_getattro;
tyProc__7LMjBc4zOHVIsNdulNv7QQ tp_setattro;
void* tp_as_buffer;
unsigned long tp_flags;
NCSTRING tp_doc;
void* tp_traverse;
void* tp_clear;
tyProc__k4RBH32nrpDxtGF9acg45zw tp_richcompare;
NI tp_weaklistoffset;
tyProc__jvPpjMAkI9bwM1B9apOphnlA tp_iter;
tyProc__jvPpjMAkI9bwM1B9apOphnlA tp_iternext;
tyObject_PyMethodDef__9aWi1PsmvCuTKIYDHHnhfcw* tp_methods;
tyObject_PyMemberDef__WC29aEeHi2Pdy9c4AkllcBTg* tp_members;
void* tp_getset;
tyObject_PyTypeObject3Obj__cRsC9bGvH9bX6A9aVx8UB6I5g* tp_base;
void* tp_dict;
tyProc__uQWqJp3WAx8fOY1h9aCwjIg tp_descr_get;
tyProc__7LMjBc4zOHVIsNdulNv7QQ tp_descr_set;
NI tp_dictoffset;
tyProc__7LMjBc4zOHVIsNdulNv7QQ tp_init;
tyProc__Cj3MN9a7OA9a51xOtsYjEwBg tp_alloc;
tyProc__eYT4U6bGFqFBUxk9b15mfOA tp_new;
tyProc__32w2ZypAyMWuajvi2Jt79cg tp_free;
void* tp_is_gc;
tyObject_PyObjectObj__aD5pkFWInXrZXinZ42cDEg* tp_bases;
void* tp_mro;
void* tp_cache;
tyObject_PyObjectObj__aD5pkFWInXrZXinZ42cDEg* tp_subclasses;
tyObject_PyObjectObj__aD5pkFWInXrZXinZ42cDEg* tp_weaklist;
tyProc__32w2ZypAyMWuajvi2Jt79cg tp_del;
unsigned int tp_version_tag;
tyProc__32w2ZypAyMWuajvi2Jt79cg tp_finalize;
tyProc__3hYcL7bVv9cte9aw9aoXtthhA tp_vectorcall;
};
N_LIB_PRIVATE TNimType NTIpymethoddef__9aWi1PsmvCuTKIYDHHnhfcw_;
extern TNimType NTIcstring__S9agCYBinaYZnGWcjTdxclg_;
N_LIB_PRIVATE TNimType NTIpycfunctionwithkeywords__uQWqJp3WAx8fOY1h9aCwjIg_;
extern TNimType NTIcint__nlCscttRCss70IBTyuBqnA_;
N_LIB_PRIVATE TNimType NTInewfunc__eYT4U6bGFqFBUxk9b15mfOA_;
N_LIB_PRIVATE TNimType NTIpymemberdef__WC29aEeHi2Pdy9c4AkllcBTg_;
extern TNimType NTIint__rR5Bzr1D5krxoo1NcNyeMA_;
N_LIB_PRIVATE TNimType NTIpyobjectobj__aD5pkFWInXrZXinZ42cDEg_;
extern TNimType NTIpointer__vr5DoT1jILTGdRlYv1OYpw_;
N_LIB_PRIVATE TNimType NTIpyobjectvarheadobj__5fAkl5kIcYJNl6VvYzZdMw_;
N_LIB_PRIVATE TNimType NTIpytypeobject51obj__cRsC9bGvH9bX6A9aVx8UB6I5g_;
N_LIB_PRIVATE TNimType NTIdestructor__32w2ZypAyMWuajvi2Jt79cg_;
N_LIB_PRIVATE TNimType NTIprintfunc__rNiGphbUW4RHd2WIj64deg_;
N_LIB_PRIVATE TNimType NTIgetattrfunc__YezmFzxOOyM9cb11Eoq1Elg_;
N_LIB_PRIVATE TNimType NTIsetattrfunc__T08W9bgbY4bOv2q64h6irpw_;
N_LIB_PRIVATE TNimType NTIreprfunc__jvPpjMAkI9bwM1B9apOphnlA_;
N_LIB_PRIVATE TNimType NTIgetattrofunc__VQ1ysQk017myXMGb79cPTVw_;
N_LIB_PRIVATE TNimType NTIsetattrofunc__7LMjBc4zOHVIsNdulNv7QQ_;
extern TNimType NTIculong__Mjfw09aZw9a49bYxYRsVFNFnQ_;
N_LIB_PRIVATE TNimType NTIrichcmpfunc__k4RBH32nrpDxtGF9acg45zw_;
N_LIB_PRIVATE TNimType NTIptrpymethoddef__5kS2EQajX4co7miu6vMuZQ_;
N_LIB_PRIVATE TNimType NTIptrpymemberdef__q1d1aN7KvGU5CrdLzkL46A_;
N_LIB_PRIVATE TNimType NTIallocfunc__Cj3MN9a7OA9a51xOtsYjEwBg_;
N_LIB_PRIVATE TNimType NTIptrpyobjectobj__AkfhTl2t5qBOGVlzmsUzlg_;
extern TNimType NTIcuint__EfDYb5NOiMBijiUDCmXqPw_;
N_LIB_PRIVATE TNimType NTIvectorcallfunc__3hYcL7bVv9cte9aw9aoXtthhA_;
N_LIB_PRIVATE TNimType NTIpytypeobject__dgEY47TsFEQv355iEJP9bPA_;
N_LIB_PRIVATE N_NIMCALL(void, nimpy_py_typesDatInit000)(void) {
static TNimNode* TM__NTBSFVABaCX7j6t0zZIyng_2_4[4];
static TNimNode* TM__NTBSFVABaCX7j6t0zZIyng_3_5[5];
static TNimNode* TM__NTBSFVABaCX7j6t0zZIyng_4_2[2];
static TNimNode* TM__NTBSFVABaCX7j6t0zZIyng_5_48[48];
static TNimNode TM__NTBSFVABaCX7j6t0zZIyng_0[64];
NTIpymethoddef__9aWi1PsmvCuTKIYDHHnhfcw_.size = sizeof(tyObject_PyMethodDef__9aWi1PsmvCuTKIYDHHnhfcw);
NTIpymethoddef__9aWi1PsmvCuTKIYDHHnhfcw_.align = NIM_ALIGNOF(tyObject_PyMethodDef__9aWi1PsmvCuTKIYDHHnhfcw);
NTIpymethoddef__9aWi1PsmvCuTKIYDHHnhfcw_.kind = 18;
NTIpymethoddef__9aWi1PsmvCuTKIYDHHnhfcw_.base = 0;
NTIpymethoddef__9aWi1PsmvCuTKIYDHHnhfcw_.flags = 1;
TM__NTBSFVABaCX7j6t0zZIyng_2_4[0] = &TM__NTBSFVABaCX7j6t0zZIyng_0[1];
TM__NTBSFVABaCX7j6t0zZIyng_0[1].kind = 1;
TM__NTBSFVABaCX7j6t0zZIyng_0[1].offset = offsetof(tyObject_PyMethodDef__9aWi1PsmvCuTKIYDHHnhfcw, ml_name);
TM__NTBSFVABaCX7j6t0zZIyng_0[1].typ = (&NTIcstring__S9agCYBinaYZnGWcjTdxclg_);
TM__NTBSFVABaCX7j6t0zZIyng_0[1].name = "ml_name";
TM__NTBSFVABaCX7j6t0zZIyng_2_4[1] = &TM__NTBSFVABaCX7j6t0zZIyng_0[2];
NTIpycfunctionwithkeywords__uQWqJp3WAx8fOY1h9aCwjIg_.size = sizeof(tyProc__uQWqJp3WAx8fOY1h9aCwjIg);
NTIpycfunctionwithkeywords__uQWqJp3WAx8fOY1h9aCwjIg_.align = NIM_ALIGNOF(tyProc__uQWqJp3WAx8fOY1h9aCwjIg);
NTIpycfunctionwithkeywords__uQWqJp3WAx8fOY1h9aCwjIg_.kind = 25;
NTIpycfunctionwithkeywords__uQWqJp3WAx8fOY1h9aCwjIg_.base = 0;
NTIpycfunctionwithkeywords__uQWqJp3WAx8fOY1h9aCwjIg_.flags = 3;
TM__NTBSFVABaCX7j6t0zZIyng_0[2].kind = 1;
TM__NTBSFVABaCX7j6t0zZIyng_0[2].offset = offsetof(tyObject_PyMethodDef__9aWi1PsmvCuTKIYDHHnhfcw, ml_meth);
TM__NTBSFVABaCX7j6t0zZIyng_0[2].typ = (&NTIpycfunctionwithkeywords__uQWqJp3WAx8fOY1h9aCwjIg_);
TM__NTBSFVABaCX7j6t0zZIyng_0[2].name = "ml_meth";
TM__NTBSFVABaCX7j6t0zZIyng_2_4[2] = &TM__NTBSFVABaCX7j6t0zZIyng_0[3];
TM__NTBSFVABaCX7j6t0zZIyng_0[3].kind = 1;
TM__NTBSFVABaCX7j6t0zZIyng_0[3].offset = offsetof(tyObject_PyMethodDef__9aWi1PsmvCuTKIYDHHnhfcw, ml_flags);
TM__NTBSFVABaCX7j6t0zZIyng_0[3].typ = (&NTIcint__nlCscttRCss70IBTyuBqnA_);
TM__NTBSFVABaCX7j6t0zZIyng_0[3].name = "ml_flags";
TM__NTBSFVABaCX7j6t0zZIyng_2_4[3] = &TM__NTBSFVABaCX7j6t0zZIyng_0[4];
TM__NTBSFVABaCX7j6t0zZIyng_0[4].kind = 1;
TM__NTBSFVABaCX7j6t0zZIyng_0[4].offset = offsetof(tyObject_PyMethodDef__9aWi1PsmvCuTKIYDHHnhfcw, ml_doc);
TM__NTBSFVABaCX7j6t0zZIyng_0[4].typ = (&NTIcstring__S9agCYBinaYZnGWcjTdxclg_);
TM__NTBSFVABaCX7j6t0zZIyng_0[4].name = "ml_doc";
TM__NTBSFVABaCX7j6t0zZIyng_0[0].len = 4; TM__NTBSFVABaCX7j6t0zZIyng_0[0].kind = 2; TM__NTBSFVABaCX7j6t0zZIyng_0[0].sons = &TM__NTBSFVABaCX7j6t0zZIyng_2_4[0];
NTIpymethoddef__9aWi1PsmvCuTKIYDHHnhfcw_.node = &TM__NTBSFVABaCX7j6t0zZIyng_0[0];
NTInewfunc__eYT4U6bGFqFBUxk9b15mfOA_.size = sizeof(tyProc__eYT4U6bGFqFBUxk9b15mfOA);
NTInewfunc__eYT4U6bGFqFBUxk9b15mfOA_.align = NIM_ALIGNOF(tyProc__eYT4U6bGFqFBUxk9b15mfOA);
NTInewfunc__eYT4U6bGFqFBUxk9b15mfOA_.kind = 25;
NTInewfunc__eYT4U6bGFqFBUxk9b15mfOA_.base = 0;
NTInewfunc__eYT4U6bGFqFBUxk9b15mfOA_.flags = 3;
NTIpymemberdef__WC29aEeHi2Pdy9c4AkllcBTg_.size = sizeof(tyObject_PyMemberDef__WC29aEeHi2Pdy9c4AkllcBTg);
NTIpymemberdef__WC29aEeHi2Pdy9c4AkllcBTg_.align = NIM_ALIGNOF(tyObject_PyMemberDef__WC29aEeHi2Pdy9c4AkllcBTg);
NTIpymemberdef__WC29aEeHi2Pdy9c4AkllcBTg_.kind = 18;
NTIpymemberdef__WC29aEeHi2Pdy9c4AkllcBTg_.base = 0;
NTIpymemberdef__WC29aEeHi2Pdy9c4AkllcBTg_.flags = 1;
TM__NTBSFVABaCX7j6t0zZIyng_3_5[0] = &TM__NTBSFVABaCX7j6t0zZIyng_0[6];
TM__NTBSFVABaCX7j6t0zZIyng_0[6].kind = 1;
TM__NTBSFVABaCX7j6t0zZIyng_0[6].offset = offsetof(tyObject_PyMemberDef__WC29aEeHi2Pdy9c4AkllcBTg, name);
TM__NTBSFVABaCX7j6t0zZIyng_0[6].typ = (&NTIcstring__S9agCYBinaYZnGWcjTdxclg_);
TM__NTBSFVABaCX7j6t0zZIyng_0[6].name = "name";
TM__NTBSFVABaCX7j6t0zZIyng_3_5[1] = &TM__NTBSFVABaCX7j6t0zZIyng_0[7];
TM__NTBSFVABaCX7j6t0zZIyng_0[7].kind = 1;
TM__NTBSFVABaCX7j6t0zZIyng_0[7].offset = offsetof(tyObject_PyMemberDef__WC29aEeHi2Pdy9c4AkllcBTg, typ);
TM__NTBSFVABaCX7j6t0zZIyng_0[7].typ = (&NTIcint__nlCscttRCss70IBTyuBqnA_);
TM__NTBSFVABaCX7j6t0zZIyng_0[7].name = "typ";
TM__NTBSFVABaCX7j6t0zZIyng_3_5[2] = &TM__NTBSFVABaCX7j6t0zZIyng_0[8];
TM__NTBSFVABaCX7j6t0zZIyng_0[8].kind = 1;
TM__NTBSFVABaCX7j6t0zZIyng_0[8].offset = offsetof(tyObject_PyMemberDef__WC29aEeHi2Pdy9c4AkllcBTg, offset);
TM__NTBSFVABaCX7j6t0zZIyng_0[8].typ = (&NTIint__rR5Bzr1D5krxoo1NcNyeMA_);
TM__NTBSFVABaCX7j6t0zZIyng_0[8].name = "offset";
TM__NTBSFVABaCX7j6t0zZIyng_3_5[3] = &TM__NTBSFVABaCX7j6t0zZIyng_0[9];
TM__NTBSFVABaCX7j6t0zZIyng_0[9].kind = 1;
TM__NTBSFVABaCX7j6t0zZIyng_0[9].offset = offsetof(tyObject_PyMemberDef__WC29aEeHi2Pdy9c4AkllcBTg, flags);
TM__NTBSFVABaCX7j6t0zZIyng_0[9].typ = (&NTIcint__nlCscttRCss70IBTyuBqnA_);
TM__NTBSFVABaCX7j6t0zZIyng_0[9].name = "flags";
TM__NTBSFVABaCX7j6t0zZIyng_3_5[4] = &TM__NTBSFVABaCX7j6t0zZIyng_0[10];
TM__NTBSFVABaCX7j6t0zZIyng_0[10].kind = 1;
TM__NTBSFVABaCX7j6t0zZIyng_0[10].offset = offsetof(tyObject_PyMemberDef__WC29aEeHi2Pdy9c4AkllcBTg, doc);
TM__NTBSFVABaCX7j6t0zZIyng_0[10].typ = (&NTIcstring__S9agCYBinaYZnGWcjTdxclg_);
TM__NTBSFVABaCX7j6t0zZIyng_0[10].name = "doc";
TM__NTBSFVABaCX7j6t0zZIyng_0[5].len = 5; TM__NTBSFVABaCX7j6t0zZIyng_0[5].kind = 2; TM__NTBSFVABaCX7j6t0zZIyng_0[5].sons = &TM__NTBSFVABaCX7j6t0zZIyng_3_5[0];
NTIpymemberdef__WC29aEeHi2Pdy9c4AkllcBTg_.node = &TM__NTBSFVABaCX7j6t0zZIyng_0[5];
NTIpyobjectobj__aD5pkFWInXrZXinZ42cDEg_.size = sizeof(tyObject_PyObjectObj__aD5pkFWInXrZXinZ42cDEg);
NTIpyobjectobj__aD5pkFWInXrZXinZ42cDEg_.align = NIM_ALIGNOF(tyObject_PyObjectObj__aD5pkFWInXrZXinZ42cDEg);
NTIpyobjectobj__aD5pkFWInXrZXinZ42cDEg_.kind = 18;
NTIpyobjectobj__aD5pkFWInXrZXinZ42cDEg_.base = 0;
NTIpyobjectobj__aD5pkFWInXrZXinZ42cDEg_.flags = 1;
TM__NTBSFVABaCX7j6t0zZIyng_4_2[0] = &TM__NTBSFVABaCX7j6t0zZIyng_0[12];
TM__NTBSFVABaCX7j6t0zZIyng_0[12].kind = 1;
TM__NTBSFVABaCX7j6t0zZIyng_0[12].offset = offsetof(tyObject_PyObjectObj__aD5pkFWInXrZXinZ42cDEg, ob_refcnt);
TM__NTBSFVABaCX7j6t0zZIyng_0[12].typ = (&NTIint__rR5Bzr1D5krxoo1NcNyeMA_);
TM__NTBSFVABaCX7j6t0zZIyng_0[12].name = "ob_refcnt";
TM__NTBSFVABaCX7j6t0zZIyng_4_2[1] = &TM__NTBSFVABaCX7j6t0zZIyng_0[13];
TM__NTBSFVABaCX7j6t0zZIyng_0[13].kind = 1;
TM__NTBSFVABaCX7j6t0zZIyng_0[13].offset = offsetof(tyObject_PyObjectObj__aD5pkFWInXrZXinZ42cDEg, ob_type);
TM__NTBSFVABaCX7j6t0zZIyng_0[13].typ = (&NTIpointer__vr5DoT1jILTGdRlYv1OYpw_);
TM__NTBSFVABaCX7j6t0zZIyng_0[13].name = "ob_type";
TM__NTBSFVABaCX7j6t0zZIyng_0[11].len = 2; TM__NTBSFVABaCX7j6t0zZIyng_0[11].kind = 2; TM__NTBSFVABaCX7j6t0zZIyng_0[11].sons = &TM__NTBSFVABaCX7j6t0zZIyng_4_2[0];
NTIpyobjectobj__aD5pkFWInXrZXinZ42cDEg_.node = &TM__NTBSFVABaCX7j6t0zZIyng_0[11];
NTIpyobjectvarheadobj__5fAkl5kIcYJNl6VvYzZdMw_.size = sizeof(tyObject_PyObjectVarHeadObj__5fAkl5kIcYJNl6VvYzZdMw);
NTIpyobjectvarheadobj__5fAkl5kIcYJNl6VvYzZdMw_.align = NIM_ALIGNOF(tyObject_PyObjectVarHeadObj__5fAkl5kIcYJNl6VvYzZdMw);
NTIpyobjectvarheadobj__5fAkl5kIcYJNl6VvYzZdMw_.kind = 18;
NTIpyobjectvarheadobj__5fAkl5kIcYJNl6VvYzZdMw_.base = (&NTIpyobjectobj__aD5pkFWInXrZXinZ42cDEg_);
NTIpyobjectvarheadobj__5fAkl5kIcYJNl6VvYzZdMw_.flags = 1;
TM__NTBSFVABaCX7j6t0zZIyng_0[14].kind = 1;
TM__NTBSFVABaCX7j6t0zZIyng_0[14].offset = offsetof(tyObject_PyObjectVarHeadObj__5fAkl5kIcYJNl6VvYzZdMw, ob_size);
TM__NTBSFVABaCX7j6t0zZIyng_0[14].typ = (&NTIint__rR5Bzr1D5krxoo1NcNyeMA_);
TM__NTBSFVABaCX7j6t0zZIyng_0[14].name = "ob_size";
NTIpyobjectvarheadobj__5fAkl5kIcYJNl6VvYzZdMw_.node = &TM__NTBSFVABaCX7j6t0zZIyng_0[14];
NTIpytypeobject51obj__cRsC9bGvH9bX6A9aVx8UB6I5g_.size = sizeof(tyObject_PyTypeObject3Obj__cRsC9bGvH9bX6A9aVx8UB6I5g);
NTIpytypeobject51obj__cRsC9bGvH9bX6A9aVx8UB6I5g_.align = NIM_ALIGNOF(tyObject_PyTypeObject3Obj__cRsC9bGvH9bX6A9aVx8UB6I5g);
NTIpytypeobject51obj__cRsC9bGvH9bX6A9aVx8UB6I5g_.kind = 18;
NTIpytypeobject51obj__cRsC9bGvH9bX6A9aVx8UB6I5g_.base = (&NTIpyobjectvarheadobj__5fAkl5kIcYJNl6VvYzZdMw_);
NTIpytypeobject51obj__cRsC9bGvH9bX6A9aVx8UB6I5g_.flags = 1;
TM__NTBSFVABaCX7j6t0zZIyng_5_48[0] = &TM__NTBSFVABaCX7j6t0zZIyng_0[16];
TM__NTBSFVABaCX7j6t0zZIyng_0[16].kind = 1;
TM__NTBSFVABaCX7j6t0zZIyng_0[16].offset = offsetof(tyObject_PyTypeObject3Obj__cRsC9bGvH9bX6A9aVx8UB6I5g, tp_name);
TM__NTBSFVABaCX7j6t0zZIyng_0[16].typ = (&NTIcstring__S9agCYBinaYZnGWcjTdxclg_);
TM__NTBSFVABaCX7j6t0zZIyng_0[16].name = "tp_name";
TM__NTBSFVABaCX7j6t0zZIyng_5_48[1] = &TM__NTBSFVABaCX7j6t0zZIyng_0[17];
TM__NTBSFVABaCX7j6t0zZIyng_0[17].kind = 1;
TM__NTBSFVABaCX7j6t0zZIyng_0[17].offset = offsetof(tyObject_PyTypeObject3Obj__cRsC9bGvH9bX6A9aVx8UB6I5g, tp_basicsize);
TM__NTBSFVABaCX7j6t0zZIyng_0[17].typ = (&NTIint__rR5Bzr1D5krxoo1NcNyeMA_);
TM__NTBSFVABaCX7j6t0zZIyng_0[17].name = "tp_basicsize";
TM__NTBSFVABaCX7j6t0zZIyng_5_48[2] = &TM__NTBSFVABaCX7j6t0zZIyng_0[18];
TM__NTBSFVABaCX7j6t0zZIyng_0[18].kind = 1;
TM__NTBSFVABaCX7j6t0zZIyng_0[18].offset = offsetof(tyObject_PyTypeObject3Obj__cRsC9bGvH9bX6A9aVx8UB6I5g, tp_itemsize);
TM__NTBSFVABaCX7j6t0zZIyng_0[18].typ = (&NTIint__rR5Bzr1D5krxoo1NcNyeMA_);
TM__NTBSFVABaCX7j6t0zZIyng_0[18].name = "tp_itemsize";
TM__NTBSFVABaCX7j6t0zZIyng_5_48[3] = &TM__NTBSFVABaCX7j6t0zZIyng_0[19];
NTIdestructor__32w2ZypAyMWuajvi2Jt79cg_.size = sizeof(tyProc__32w2ZypAyMWuajvi2Jt79cg);
NTIdestructor__32w2ZypAyMWuajvi2Jt79cg_.align = NIM_ALIGNOF(tyProc__32w2ZypAyMWuajvi2Jt79cg);
NTIdestructor__32w2ZypAyMWuajvi2Jt79cg_.kind = 25;
NTIdestructor__32w2ZypAyMWuajvi2Jt79cg_.base = 0;
NTIdestructor__32w2ZypAyMWuajvi2Jt79cg_.flags = 3;
TM__NTBSFVABaCX7j6t0zZIyng_0[19].kind = 1;
TM__NTBSFVABaCX7j6t0zZIyng_0[19].offset = offsetof(tyObject_PyTypeObject3Obj__cRsC9bGvH9bX6A9aVx8UB6I5g, tp_dealloc);
TM__NTBSFVABaCX7j6t0zZIyng_0[19].typ = (&NTIdestructor__32w2ZypAyMWuajvi2Jt79cg_);
TM__NTBSFVABaCX7j6t0zZIyng_0[19].name = "tp_dealloc";
TM__NTBSFVABaCX7j6t0zZIyng_5_48[4] = &TM__NTBSFVABaCX7j6t0zZIyng_0[20];
NTIprintfunc__rNiGphbUW4RHd2WIj64deg_.size = sizeof(tyProc__rNiGphbUW4RHd2WIj64deg);
NTIprintfunc__rNiGphbUW4RHd2WIj64deg_.align = NIM_ALIGNOF(tyProc__rNiGphbUW4RHd2WIj64deg);
NTIprintfunc__rNiGphbUW4RHd2WIj64deg_.kind = 25;
NTIprintfunc__rNiGphbUW4RHd2WIj64deg_.base = 0;
NTIprintfunc__rNiGphbUW4RHd2WIj64deg_.flags = 3;
TM__NTBSFVABaCX7j6t0zZIyng_0[20].kind = 1;
TM__NTBSFVABaCX7j6t0zZIyng_0[20].offset = offsetof(tyObject_PyTypeObject3Obj__cRsC9bGvH9bX6A9aVx8UB6I5g, tp_print);
TM__NTBSFVABaCX7j6t0zZIyng_0[20].typ = (&NTIprintfunc__rNiGphbUW4RHd2WIj64deg_);
TM__NTBSFVABaCX7j6t0zZIyng_0[20].name = "tp_print";
TM__NTBSFVABaCX7j6t0zZIyng_5_48[5] = &TM__NTBSFVABaCX7j6t0zZIyng_0[21];
NTIgetattrfunc__YezmFzxOOyM9cb11Eoq1Elg_.size = sizeof(tyProc__YezmFzxOOyM9cb11Eoq1Elg);
NTIgetattrfunc__YezmFzxOOyM9cb11Eoq1Elg_.align = NIM_ALIGNOF(tyProc__YezmFzxOOyM9cb11Eoq1Elg);
NTIgetattrfunc__YezmFzxOOyM9cb11Eoq1Elg_.kind = 25;
NTIgetattrfunc__YezmFzxOOyM9cb11Eoq1Elg_.base = 0;
NTIgetattrfunc__YezmFzxOOyM9cb11Eoq1Elg_.flags = 3;
TM__NTBSFVABaCX7j6t0zZIyng_0[21].kind = 1;
TM__NTBSFVABaCX7j6t0zZIyng_0[21].offset = offsetof(tyObject_PyTypeObject3Obj__cRsC9bGvH9bX6A9aVx8UB6I5g, tp_getattr);
TM__NTBSFVABaCX7j6t0zZIyng_0[21].typ = (&NTIgetattrfunc__YezmFzxOOyM9cb11Eoq1Elg_);
TM__NTBSFVABaCX7j6t0zZIyng_0[21].name = "tp_getattr";
TM__NTBSFVABaCX7j6t0zZIyng_5_48[6] = &TM__NTBSFVABaCX7j6t0zZIyng_0[22];
NTIsetattrfunc__T08W9bgbY4bOv2q64h6irpw_.size = sizeof(tyProc__T08W9bgbY4bOv2q64h6irpw);
NTIsetattrfunc__T08W9bgbY4bOv2q64h6irpw_.align = NIM_ALIGNOF(tyProc__T08W9bgbY4bOv2q64h6irpw);
NTIsetattrfunc__T08W9bgbY4bOv2q64h6irpw_.kind = 25;
NTIsetattrfunc__T08W9bgbY4bOv2q64h6irpw_.base = 0;
NTIsetattrfunc__T08W9bgbY4bOv2q64h6irpw_.flags = 3;
TM__NTBSFVABaCX7j6t0zZIyng_0[22].kind = 1;
TM__NTBSFVABaCX7j6t0zZIyng_0[22].offset = offsetof(tyObject_PyTypeObject3Obj__cRsC9bGvH9bX6A9aVx8UB6I5g, tp_setattr);
TM__NTBSFVABaCX7j6t0zZIyng_0[22].typ = (&NTIsetattrfunc__T08W9bgbY4bOv2q64h6irpw_);
TM__NTBSFVABaCX7j6t0zZIyng_0[22].name = "tp_setattr";
TM__NTBSFVABaCX7j6t0zZIyng_5_48[7] = &TM__NTBSFVABaCX7j6t0zZIyng_0[23];
TM__NTBSFVABaCX7j6t0zZIyng_0[23].kind = 1;
TM__NTBSFVABaCX7j6t0zZIyng_0[23].offset = offsetof(tyObject_PyTypeObject3Obj__cRsC9bGvH9bX6A9aVx8UB6I5g, tp_as_async);
TM__NTBSFVABaCX7j6t0zZIyng_0[23].typ = (&NTIpointer__vr5DoT1jILTGdRlYv1OYpw_);
TM__NTBSFVABaCX7j6t0zZIyng_0[23].name = "tp_as_async";
TM__NTBSFVABaCX7j6t0zZIyng_5_48[8] = &TM__NTBSFVABaCX7j6t0zZIyng_0[24];
NTIreprfunc__jvPpjMAkI9bwM1B9apOphnlA_.size = sizeof(tyProc__jvPpjMAkI9bwM1B9apOphnlA);
NTIreprfunc__jvPpjMAkI9bwM1B9apOphnlA_.align = NIM_ALIGNOF(tyProc__jvPpjMAkI9bwM1B9apOphnlA);
NTIreprfunc__jvPpjMAkI9bwM1B9apOphnlA_.kind = 25;
NTIreprfunc__jvPpjMAkI9bwM1B9apOphnlA_.base = 0;
NTIreprfunc__jvPpjMAkI9bwM1B9apOphnlA_.flags = 3;
TM__NTBSFVABaCX7j6t0zZIyng_0[24].kind = 1;
TM__NTBSFVABaCX7j6t0zZIyng_0[24].offset = offsetof(tyObject_PyTypeObject3Obj__cRsC9bGvH9bX6A9aVx8UB6I5g, tp_repr);
TM__NTBSFVABaCX7j6t0zZIyng_0[24].typ = (&NTIreprfunc__jvPpjMAkI9bwM1B9apOphnlA_);
TM__NTBSFVABaCX7j6t0zZIyng_0[24].name = "tp_repr";
TM__NTBSFVABaCX7j6t0zZIyng_5_48[9] = &TM__NTBSFVABaCX7j6t0zZIyng_0[25];
TM__NTBSFVABaCX7j6t0zZIyng_0[25].kind = 1;
TM__NTBSFVABaCX7j6t0zZIyng_0[25].offset = offsetof(tyObject_PyTypeObject3Obj__cRsC9bGvH9bX6A9aVx8UB6I5g, tp_as_number);
TM__NTBSFVABaCX7j6t0zZIyng_0[25].typ = (&NTIpointer__vr5DoT1jILTGdRlYv1OYpw_);
TM__NTBSFVABaCX7j6t0zZIyng_0[25].name = "tp_as_number";
TM__NTBSFVABaCX7j6t0zZIyng_5_48[10] = &TM__NTBSFVABaCX7j6t0zZIyng_0[26];
TM__NTBSFVABaCX7j6t0zZIyng_0[26].kind = 1;
TM__NTBSFVABaCX7j6t0zZIyng_0[26].offset = offsetof(tyObject_PyTypeObject3Obj__cRsC9bGvH9bX6A9aVx8UB6I5g, tp_as_sequence);
TM__NTBSFVABaCX7j6t0zZIyng_0[26].typ = (&NTIpointer__vr5DoT1jILTGdRlYv1OYpw_);
TM__NTBSFVABaCX7j6t0zZIyng_0[26].name = "tp_as_sequence";
TM__NTBSFVABaCX7j6t0zZIyng_5_48[11] = &TM__NTBSFVABaCX7j6t0zZIyng_0[27];
TM__NTBSFVABaCX7j6t0zZIyng_0[27].kind = 1;
TM__NTBSFVABaCX7j6t0zZIyng_0[27].offset = offsetof(tyObject_PyTypeObject3Obj__cRsC9bGvH9bX6A9aVx8UB6I5g, tp_as_mapping);
TM__NTBSFVABaCX7j6t0zZIyng_0[27].typ = (&NTIpointer__vr5DoT1jILTGdRlYv1OYpw_);
TM__NTBSFVABaCX7j6t0zZIyng_0[27].name = "tp_as_mapping";
TM__NTBSFVABaCX7j6t0zZIyng_5_48[12] = &TM__NTBSFVABaCX7j6t0zZIyng_0[28];
TM__NTBSFVABaCX7j6t0zZIyng_0[28].kind = 1;
TM__NTBSFVABaCX7j6t0zZIyng_0[28].offset = offsetof(tyObject_PyTypeObject3Obj__cRsC9bGvH9bX6A9aVx8UB6I5g, tp_hash);
TM__NTBSFVABaCX7j6t0zZIyng_0[28].typ = (&NTIpointer__vr5DoT1jILTGdRlYv1OYpw_);
TM__NTBSFVABaCX7j6t0zZIyng_0[28].name = "tp_hash";
TM__NTBSFVABaCX7j6t0zZIyng_5_48[13] = &TM__NTBSFVABaCX7j6t0zZIyng_0[29];
TM__NTBSFVABaCX7j6t0zZIyng_0[29].kind = 1;
TM__NTBSFVABaCX7j6t0zZIyng_0[29].offset = offsetof(tyObject_PyTypeObject3Obj__cRsC9bGvH9bX6A9aVx8UB6I5g, tp_call);
TM__NTBSFVABaCX7j6t0zZIyng_0[29].typ = (&NTIpointer__vr5DoT1jILTGdRlYv1OYpw_);
TM__NTBSFVABaCX7j6t0zZIyng_0[29].name = "tp_call";
TM__NTBSFVABaCX7j6t0zZIyng_5_48[14] = &TM__NTBSFVABaCX7j6t0zZIyng_0[30];
TM__NTBSFVABaCX7j6t0zZIyng_0[30].kind = 1;
TM__NTBSFVABaCX7j6t0zZIyng_0[30].offset = offsetof(tyObject_PyTypeObject3Obj__cRsC9bGvH9bX6A9aVx8UB6I5g, tp_str);
TM__NTBSFVABaCX7j6t0zZIyng_0[30].typ = (&NTIreprfunc__jvPpjMAkI9bwM1B9apOphnlA_);
TM__NTBSFVABaCX7j6t0zZIyng_0[30].name = "tp_str";
TM__NTBSFVABaCX7j6t0zZIyng_5_48[15] = &TM__NTBSFVABaCX7j6t0zZIyng_0[31];
NTIgetattrofunc__VQ1ysQk017myXMGb79cPTVw_.size = sizeof(tyProc__VQ1ysQk017myXMGb79cPTVw);
NTIgetattrofunc__VQ1ysQk017myXMGb79cPTVw_.align = NIM_ALIGNOF(tyProc__VQ1ysQk017myXMGb79cPTVw);
NTIgetattrofunc__VQ1ysQk017myXMGb79cPTVw_.kind = 25;
NTIgetattrofunc__VQ1ysQk017myXMGb79cPTVw_.base = 0;
NTIgetattrofunc__VQ1ysQk017myXMGb79cPTVw_.flags = 3;
TM__NTBSFVABaCX7j6t0zZIyng_0[31].kind = 1;
TM__NTBSFVABaCX7j6t0zZIyng_0[31].offset = offsetof(tyObject_PyTypeObject3Obj__cRsC9bGvH9bX6A9aVx8UB6I5g, tp_getattro);
TM__NTBSFVABaCX7j6t0zZIyng_0[31].typ = (&NTIgetattrofunc__VQ1ysQk017myXMGb79cPTVw_);
TM__NTBSFVABaCX7j6t0zZIyng_0[31].name = "tp_getattro";
TM__NTBSFVABaCX7j6t0zZIyng_5_48[16] = &TM__NTBSFVABaCX7j6t0zZIyng_0[32];
NTIsetattrofunc__7LMjBc4zOHVIsNdulNv7QQ_.size = sizeof(tyProc__7LMjBc4zOHVIsNdulNv7QQ);
NTIsetattrofunc__7LMjBc4zOHVIsNdulNv7QQ_.align = NIM_ALIGNOF(tyProc__7LMjBc4zOHVIsNdulNv7QQ);
NTIsetattrofunc__7LMjBc4zOHVIsNdulNv7QQ_.kind = 25;
NTIsetattrofunc__7LMjBc4zOHVIsNdulNv7QQ_.base = 0;
NTIsetattrofunc__7LMjBc4zOHVIsNdulNv7QQ_.flags = 3;
TM__NTBSFVABaCX7j6t0zZIyng_0[32].kind = 1;
TM__NTBSFVABaCX7j6t0zZIyng_0[32].offset = offsetof(tyObject_PyTypeObject3Obj__cRsC9bGvH9bX6A9aVx8UB6I5g, tp_setattro);
TM__NTBSFVABaCX7j6t0zZIyng_0[32].typ = (&NTIsetattrofunc__7LMjBc4zOHVIsNdulNv7QQ_);
TM__NTBSFVABaCX7j6t0zZIyng_0[32].name = "tp_setattro";
TM__NTBSFVABaCX7j6t0zZIyng_5_48[17] = &TM__NTBSFVABaCX7j6t0zZIyng_0[33];
TM__NTBSFVABaCX7j6t0zZIyng_0[33].kind = 1;
TM__NTBSFVABaCX7j6t0zZIyng_0[33].offset = offsetof(tyObject_PyTypeObject3Obj__cRsC9bGvH9bX6A9aVx8UB6I5g, tp_as_buffer);
TM__NTBSFVABaCX7j6t0zZIyng_0[33].typ = (&NTIpointer__vr5DoT1jILTGdRlYv1OYpw_);
TM__NTBSFVABaCX7j6t0zZIyng_0[33].name = "tp_as_buffer";
TM__NTBSFVABaCX7j6t0zZIyng_5_48[18] = &TM__NTBSFVABaCX7j6t0zZIyng_0[34];
TM__NTBSFVABaCX7j6t0zZIyng_0[34].kind = 1;
TM__NTBSFVABaCX7j6t0zZIyng_0[34].offset = offsetof(tyObject_PyTypeObject3Obj__cRsC9bGvH9bX6A9aVx8UB6I5g, tp_flags);
TM__NTBSFVABaCX7j6t0zZIyng_0[34].typ = (&NTIculong__Mjfw09aZw9a49bYxYRsVFNFnQ_);
TM__NTBSFVABaCX7j6t0zZIyng_0[34].name = "tp_flags";
TM__NTBSFVABaCX7j6t0zZIyng_5_48[19] = &TM__NTBSFVABaCX7j6t0zZIyng_0[35];
TM__NTBSFVABaCX7j6t0zZIyng_0[35].kind = 1;
TM__NTBSFVABaCX7j6t0zZIyng_0[35].offset = offsetof(tyObject_PyTypeObject3Obj__cRsC9bGvH9bX6A9aVx8UB6I5g, tp_doc);
TM__NTBSFVABaCX7j6t0zZIyng_0[35].typ = (&NTIcstring__S9agCYBinaYZnGWcjTdxclg_);
TM__NTBSFVABaCX7j6t0zZIyng_0[35].name = "tp_doc";
TM__NTBSFVABaCX7j6t0zZIyng_5_48[20] = &TM__NTBSFVABaCX7j6t0zZIyng_0[36];
TM__NTBSFVABaCX7j6t0zZIyng_0[36].kind = 1;
TM__NTBSFVABaCX7j6t0zZIyng_0[36].offset = offsetof(tyObject_PyTypeObject3Obj__cRsC9bGvH9bX6A9aVx8UB6I5g, tp_traverse);
TM__NTBSFVABaCX7j6t0zZIyng_0[36].typ = (&NTIpointer__vr5DoT1jILTGdRlYv1OYpw_);
TM__NTBSFVABaCX7j6t0zZIyng_0[36].name = "tp_traverse";
TM__NTBSFVABaCX7j6t0zZIyng_5_48[21] = &TM__NTBSFVABaCX7j6t0zZIyng_0[37];
TM__NTBSFVABaCX7j6t0zZIyng_0[37].kind = 1;
TM__NTBSFVABaCX7j6t0zZIyng_0[37].offset = offsetof(tyObject_PyTypeObject3Obj__cRsC9bGvH9bX6A9aVx8UB6I5g, tp_clear);
TM__NTBSFVABaCX7j6t0zZIyng_0[37].typ = (&NTIpointer__vr5DoT1jILTGdRlYv1OYpw_);
TM__NTBSFVABaCX7j6t0zZIyng_0[37].name = "tp_clear";
TM__NTBSFVABaCX7j6t0zZIyng_5_48[22] = &TM__NTBSFVABaCX7j6t0zZIyng_0[38];
NTIrichcmpfunc__k4RBH32nrpDxtGF9acg45zw_.size = sizeof(tyProc__k4RBH32nrpDxtGF9acg45zw);
NTIrichcmpfunc__k4RBH32nrpDxtGF9acg45zw_.align = NIM_ALIGNOF(tyProc__k4RBH32nrpDxtGF9acg45zw);
NTIrichcmpfunc__k4RBH32nrpDxtGF9acg45zw_.kind = 25;
NTIrichcmpfunc__k4RBH32nrpDxtGF9acg45zw_.base = 0;
NTIrichcmpfunc__k4RBH32nrpDxtGF9acg45zw_.flags = 3;
TM__NTBSFVABaCX7j6t0zZIyng_0[38].kind = 1;
TM__NTBSFVABaCX7j6t0zZIyng_0[38].offset = offsetof(tyObject_PyTypeObject3Obj__cRsC9bGvH9bX6A9aVx8UB6I5g, tp_richcompare);
TM__NTBSFVABaCX7j6t0zZIyng_0[38].typ = (&NTIrichcmpfunc__k4RBH32nrpDxtGF9acg45zw_);
TM__NTBSFVABaCX7j6t0zZIyng_0[38].name = "tp_richcompare";
TM__NTBSFVABaCX7j6t0zZIyng_5_48[23] = &TM__NTBSFVABaCX7j6t0zZIyng_0[39];
TM__NTBSFVABaCX7j6t0zZIyng_0[39].kind = 1;
TM__NTBSFVABaCX7j6t0zZIyng_0[39].offset = offsetof(tyObject_PyTypeObject3Obj__cRsC9bGvH9bX6A9aVx8UB6I5g, tp_weaklistoffset);
TM__NTBSFVABaCX7j6t0zZIyng_0[39].typ = (&NTIint__rR5Bzr1D5krxoo1NcNyeMA_);
TM__NTBSFVABaCX7j6t0zZIyng_0[39].name = "tp_weaklistoffset";
TM__NTBSFVABaCX7j6t0zZIyng_5_48[24] = &TM__NTBSFVABaCX7j6t0zZIyng_0[40];
TM__NTBSFVABaCX7j6t0zZIyng_0[40].kind = 1;
TM__NTBSFVABaCX7j6t0zZIyng_0[40].offset = offsetof(tyObject_PyTypeObject3Obj__cRsC9bGvH9bX6A9aVx8UB6I5g, tp_iter);
TM__NTBSFVABaCX7j6t0zZIyng_0[40].typ = (&NTIreprfunc__jvPpjMAkI9bwM1B9apOphnlA_);
TM__NTBSFVABaCX7j6t0zZIyng_0[40].name = "tp_iter";
TM__NTBSFVABaCX7j6t0zZIyng_5_48[25] = &TM__NTBSFVABaCX7j6t0zZIyng_0[41];
TM__NTBSFVABaCX7j6t0zZIyng_0[41].kind = 1;
TM__NTBSFVABaCX7j6t0zZIyng_0[41].offset = offsetof(tyObject_PyTypeObject3Obj__cRsC9bGvH9bX6A9aVx8UB6I5g, tp_iternext);
TM__NTBSFVABaCX7j6t0zZIyng_0[41].typ = (&NTIreprfunc__jvPpjMAkI9bwM1B9apOphnlA_);
TM__NTBSFVABaCX7j6t0zZIyng_0[41].name = "tp_iternext";
TM__NTBSFVABaCX7j6t0zZIyng_5_48[26] = &TM__NTBSFVABaCX7j6t0zZIyng_0[42];
NTIptrpymethoddef__5kS2EQajX4co7miu6vMuZQ_.size = sizeof(tyObject_PyMethodDef__9aWi1PsmvCuTKIYDHHnhfcw*);
NTIptrpymethoddef__5kS2EQajX4co7miu6vMuZQ_.align = NIM_ALIGNOF(tyObject_PyMethodDef__9aWi1PsmvCuTKIYDHHnhfcw*);
NTIptrpymethoddef__5kS2EQajX4co7miu6vMuZQ_.kind = 21;
NTIptrpymethoddef__5kS2EQajX4co7miu6vMuZQ_.base = (&NTIpymethoddef__9aWi1PsmvCuTKIYDHHnhfcw_);
NTIptrpymethoddef__5kS2EQajX4co7miu6vMuZQ_.flags = 3;
TM__NTBSFVABaCX7j6t0zZIyng_0[42].kind = 1;
TM__NTBSFVABaCX7j6t0zZIyng_0[42].offset = offsetof(tyObject_PyTypeObject3Obj__cRsC9bGvH9bX6A9aVx8UB6I5g, tp_methods);
TM__NTBSFVABaCX7j6t0zZIyng_0[42].typ = (&NTIptrpymethoddef__5kS2EQajX4co7miu6vMuZQ_);
TM__NTBSFVABaCX7j6t0zZIyng_0[42].name = "tp_methods";
TM__NTBSFVABaCX7j6t0zZIyng_5_48[27] = &TM__NTBSFVABaCX7j6t0zZIyng_0[43];
NTIptrpymemberdef__q1d1aN7KvGU5CrdLzkL46A_.size = sizeof(tyObject_PyMemberDef__WC29aEeHi2Pdy9c4AkllcBTg*);
NTIptrpymemberdef__q1d1aN7KvGU5CrdLzkL46A_.align = NIM_ALIGNOF(tyObject_PyMemberDef__WC29aEeHi2Pdy9c4AkllcBTg*);
NTIptrpymemberdef__q1d1aN7KvGU5CrdLzkL46A_.kind = 21;
NTIptrpymemberdef__q1d1aN7KvGU5CrdLzkL46A_.base = (&NTIpymemberdef__WC29aEeHi2Pdy9c4AkllcBTg_);
NTIptrpymemberdef__q1d1aN7KvGU5CrdLzkL46A_.flags = 3;
TM__NTBSFVABaCX7j6t0zZIyng_0[43].kind = 1;
TM__NTBSFVABaCX7j6t0zZIyng_0[43].offset = offsetof(tyObject_PyTypeObject3Obj__cRsC9bGvH9bX6A9aVx8UB6I5g, tp_members);
TM__NTBSFVABaCX7j6t0zZIyng_0[43].typ = (&NTIptrpymemberdef__q1d1aN7KvGU5CrdLzkL46A_);
TM__NTBSFVABaCX7j6t0zZIyng_0[43].name = "tp_members";
TM__NTBSFVABaCX7j6t0zZIyng_5_48[28] = &TM__NTBSFVABaCX7j6t0zZIyng_0[44];
TM__NTBSFVABaCX7j6t0zZIyng_0[44].kind = 1;
TM__NTBSFVABaCX7j6t0zZIyng_0[44].offset = offsetof(tyObject_PyTypeObject3Obj__cRsC9bGvH9bX6A9aVx8UB6I5g, tp_getset);
TM__NTBSFVABaCX7j6t0zZIyng_0[44].typ = (&NTIpointer__vr5DoT1jILTGdRlYv1OYpw_);
TM__NTBSFVABaCX7j6t0zZIyng_0[44].name = "tp_getset";
TM__NTBSFVABaCX7j6t0zZIyng_5_48[29] = &TM__NTBSFVABaCX7j6t0zZIyng_0[45];
TM__NTBSFVABaCX7j6t0zZIyng_0[45].kind = 1;
TM__NTBSFVABaCX7j6t0zZIyng_0[45].offset = offsetof(tyObject_PyTypeObject3Obj__cRsC9bGvH9bX6A9aVx8UB6I5g, tp_base);
TM__NTBSFVABaCX7j6t0zZIyng_0[45].typ = (&NTIpytypeobject__dgEY47TsFEQv355iEJP9bPA_);
TM__NTBSFVABaCX7j6t0zZIyng_0[45].name = "tp_base";
TM__NTBSFVABaCX7j6t0zZIyng_5_48[30] = &TM__NTBSFVABaCX7j6t0zZIyng_0[46];
TM__NTBSFVABaCX7j6t0zZIyng_0[46].kind = 1;
TM__NTBSFVABaCX7j6t0zZIyng_0[46].offset = offsetof(tyObject_PyTypeObject3Obj__cRsC9bGvH9bX6A9aVx8UB6I5g, tp_dict);
TM__NTBSFVABaCX7j6t0zZIyng_0[46].typ = (&NTIpointer__vr5DoT1jILTGdRlYv1OYpw_);
TM__NTBSFVABaCX7j6t0zZIyng_0[46].name = "tp_dict";
TM__NTBSFVABaCX7j6t0zZIyng_5_48[31] = &TM__NTBSFVABaCX7j6t0zZIyng_0[47];
TM__NTBSFVABaCX7j6t0zZIyng_0[47].kind = 1;
TM__NTBSFVABaCX7j6t0zZIyng_0[47].offset = offsetof(tyObject_PyTypeObject3Obj__cRsC9bGvH9bX6A9aVx8UB6I5g, tp_descr_get);
TM__NTBSFVABaCX7j6t0zZIyng_0[47].typ = (&NTIpycfunctionwithkeywords__uQWqJp3WAx8fOY1h9aCwjIg_);
TM__NTBSFVABaCX7j6t0zZIyng_0[47].name = "tp_descr_get";
TM__NTBSFVABaCX7j6t0zZIyng_5_48[32] = &TM__NTBSFVABaCX7j6t0zZIyng_0[48];
TM__NTBSFVABaCX7j6t0zZIyng_0[48].kind = 1;
TM__NTBSFVABaCX7j6t0zZIyng_0[48].offset = offsetof(tyObject_PyTypeObject3Obj__cRsC9bGvH9bX6A9aVx8UB6I5g, tp_descr_set);
TM__NTBSFVABaCX7j6t0zZIyng_0[48].typ = (&NTIsetattrofunc__7LMjBc4zOHVIsNdulNv7QQ_);
TM__NTBSFVABaCX7j6t0zZIyng_0[48].name = "tp_descr_set";
TM__NTBSFVABaCX7j6t0zZIyng_5_48[33] = &TM__NTBSFVABaCX7j6t0zZIyng_0[49];
TM__NTBSFVABaCX7j6t0zZIyng_0[49].kind = 1;
TM__NTBSFVABaCX7j6t0zZIyng_0[49].offset = offsetof(tyObject_PyTypeObject3Obj__cRsC9bGvH9bX6A9aVx8UB6I5g, tp_dictoffset);
TM__NTBSFVABaCX7j6t0zZIyng_0[49].typ = (&NTIint__rR5Bzr1D5krxoo1NcNyeMA_);
TM__NTBSFVABaCX7j6t0zZIyng_0[49].name = "tp_dictoffset";
TM__NTBSFVABaCX7j6t0zZIyng_5_48[34] = &TM__NTBSFVABaCX7j6t0zZIyng_0[50];
TM__NTBSFVABaCX7j6t0zZIyng_0[50].kind = 1;
TM__NTBSFVABaCX7j6t0zZIyng_0[50].offset = offsetof(tyObject_PyTypeObject3Obj__cRsC9bGvH9bX6A9aVx8UB6I5g, tp_init);
TM__NTBSFVABaCX7j6t0zZIyng_0[50].typ = (&NTIsetattrofunc__7LMjBc4zOHVIsNdulNv7QQ_);
TM__NTBSFVABaCX7j6t0zZIyng_0[50].name = "tp_init";
TM__NTBSFVABaCX7j6t0zZIyng_5_48[35] = &TM__NTBSFVABaCX7j6t0zZIyng_0[51];
NTIallocfunc__Cj3MN9a7OA9a51xOtsYjEwBg_.size = sizeof(tyProc__Cj3MN9a7OA9a51xOtsYjEwBg);
NTIallocfunc__Cj3MN9a7OA9a51xOtsYjEwBg_.align = NIM_ALIGNOF(tyProc__Cj3MN9a7OA9a51xOtsYjEwBg);
NTIallocfunc__Cj3MN9a7OA9a51xOtsYjEwBg_.kind = 25;
NTIallocfunc__Cj3MN9a7OA9a51xOtsYjEwBg_.base = 0;
NTIallocfunc__Cj3MN9a7OA9a51xOtsYjEwBg_.flags = 3;
TM__NTBSFVABaCX7j6t0zZIyng_0[51].kind = 1;
TM__NTBSFVABaCX7j6t0zZIyng_0[51].offset = offsetof(tyObject_PyTypeObject3Obj__cRsC9bGvH9bX6A9aVx8UB6I5g, tp_alloc);
TM__NTBSFVABaCX7j6t0zZIyng_0[51].typ = (&NTIallocfunc__Cj3MN9a7OA9a51xOtsYjEwBg_);
TM__NTBSFVABaCX7j6t0zZIyng_0[51].name = "tp_alloc";
TM__NTBSFVABaCX7j6t0zZIyng_5_48[36] = &TM__NTBSFVABaCX7j6t0zZIyng_0[52];
TM__NTBSFVABaCX7j6t0zZIyng_0[52].kind = 1;
TM__NTBSFVABaCX7j6t0zZIyng_0[52].offset = offsetof(tyObject_PyTypeObject3Obj__cRsC9bGvH9bX6A9aVx8UB6I5g, tp_new);
TM__NTBSFVABaCX7j6t0zZIyng_0[52].typ = (&NTInewfunc__eYT4U6bGFqFBUxk9b15mfOA_);
TM__NTBSFVABaCX7j6t0zZIyng_0[52].name = "tp_new";
TM__NTBSFVABaCX7j6t0zZIyng_5_48[37] = &TM__NTBSFVABaCX7j6t0zZIyng_0[53];
TM__NTBSFVABaCX7j6t0zZIyng_0[53].kind = 1;
TM__NTBSFVABaCX7j6t0zZIyng_0[53].offset = offsetof(tyObject_PyTypeObject3Obj__cRsC9bGvH9bX6A9aVx8UB6I5g, tp_free);
TM__NTBSFVABaCX7j6t0zZIyng_0[53].typ = (&NTIdestructor__32w2ZypAyMWuajvi2Jt79cg_);
TM__NTBSFVABaCX7j6t0zZIyng_0[53].name = "tp_free";
TM__NTBSFVABaCX7j6t0zZIyng_5_48[38] = &TM__NTBSFVABaCX7j6t0zZIyng_0[54];
TM__NTBSFVABaCX7j6t0zZIyng_0[54].kind = 1;
TM__NTBSFVABaCX7j6t0zZIyng_0[54].offset = offsetof(tyObject_PyTypeObject3Obj__cRsC9bGvH9bX6A9aVx8UB6I5g, tp_is_gc);
TM__NTBSFVABaCX7j6t0zZIyng_0[54].typ = (&NTIpointer__vr5DoT1jILTGdRlYv1OYpw_);
TM__NTBSFVABaCX7j6t0zZIyng_0[54].name = "tp_is_gc";
TM__NTBSFVABaCX7j6t0zZIyng_5_48[39] = &TM__NTBSFVABaCX7j6t0zZIyng_0[55];
NTIptrpyobjectobj__AkfhTl2t5qBOGVlzmsUzlg_.size = sizeof(tyObject_PyObjectObj__aD5pkFWInXrZXinZ42cDEg*);
NTIptrpyobjectobj__AkfhTl2t5qBOGVlzmsUzlg_.align = NIM_ALIGNOF(tyObject_PyObjectObj__aD5pkFWInXrZXinZ42cDEg*);
NTIptrpyobjectobj__AkfhTl2t5qBOGVlzmsUzlg_.kind = 21;
NTIptrpyobjectobj__AkfhTl2t5qBOGVlzmsUzlg_.base = (&NTIpyobjectobj__aD5pkFWInXrZXinZ42cDEg_);
NTIptrpyobjectobj__AkfhTl2t5qBOGVlzmsUzlg_.flags = 3;
TM__NTBSFVABaCX7j6t0zZIyng_0[55].kind = 1;
TM__NTBSFVABaCX7j6t0zZIyng_0[55].offset = offsetof(tyObject_PyTypeObject3Obj__cRsC9bGvH9bX6A9aVx8UB6I5g, tp_bases);
TM__NTBSFVABaCX7j6t0zZIyng_0[55].typ = (&NTIptrpyobjectobj__AkfhTl2t5qBOGVlzmsUzlg_);
TM__NTBSFVABaCX7j6t0zZIyng_0[55].name = "tp_bases";
TM__NTBSFVABaCX7j6t0zZIyng_5_48[40] = &TM__NTBSFVABaCX7j6t0zZIyng_0[56];
TM__NTBSFVABaCX7j6t0zZIyng_0[56].kind = 1;
TM__NTBSFVABaCX7j6t0zZIyng_0[56].offset = offsetof(tyObject_PyTypeObject3Obj__cRsC9bGvH9bX6A9aVx8UB6I5g, tp_mro);
TM__NTBSFVABaCX7j6t0zZIyng_0[56].typ = (&NTIpointer__vr5DoT1jILTGdRlYv1OYpw_);
TM__NTBSFVABaCX7j6t0zZIyng_0[56].name = "tp_mro";
TM__NTBSFVABaCX7j6t0zZIyng_5_48[41] = &TM__NTBSFVABaCX7j6t0zZIyng_0[57];
TM__NTBSFVABaCX7j6t0zZIyng_0[57].kind = 1;
TM__NTBSFVABaCX7j6t0zZIyng_0[57].offset = offsetof(tyObject_PyTypeObject3Obj__cRsC9bGvH9bX6A9aVx8UB6I5g, tp_cache);
TM__NTBSFVABaCX7j6t0zZIyng_0[57].typ = (&NTIpointer__vr5DoT1jILTGdRlYv1OYpw_);
TM__NTBSFVABaCX7j6t0zZIyng_0[57].name = "tp_cache";
TM__NTBSFVABaCX7j6t0zZIyng_5_48[42] = &TM__NTBSFVABaCX7j6t0zZIyng_0[58];
TM__NTBSFVABaCX7j6t0zZIyng_0[58].kind = 1;
TM__NTBSFVABaCX7j6t0zZIyng_0[58].offset = offsetof(tyObject_PyTypeObject3Obj__cRsC9bGvH9bX6A9aVx8UB6I5g, tp_subclasses);
TM__NTBSFVABaCX7j6t0zZIyng_0[58].typ = (&NTIptrpyobjectobj__AkfhTl2t5qBOGVlzmsUzlg_);
TM__NTBSFVABaCX7j6t0zZIyng_0[58].name = "tp_subclasses";
TM__NTBSFVABaCX7j6t0zZIyng_5_48[43] = &TM__NTBSFVABaCX7j6t0zZIyng_0[59];
TM__NTBSFVABaCX7j6t0zZIyng_0[59].kind = 1;
TM__NTBSFVABaCX7j6t0zZIyng_0[59].offset = offsetof(tyObject_PyTypeObject3Obj__cRsC9bGvH9bX6A9aVx8UB6I5g, tp_weaklist);
TM__NTBSFVABaCX7j6t0zZIyng_0[59].typ = (&NTIptrpyobjectobj__AkfhTl2t5qBOGVlzmsUzlg_);
TM__NTBSFVABaCX7j6t0zZIyng_0[59].name = "tp_weaklist";
TM__NTBSFVABaCX7j6t0zZIyng_5_48[44] = &TM__NTBSFVABaCX7j6t0zZIyng_0[60];
TM__NTBSFVABaCX7j6t0zZIyng_0[60].kind = 1;
TM__NTBSFVABaCX7j6t0zZIyng_0[60].offset = offsetof(tyObject_PyTypeObject3Obj__cRsC9bGvH9bX6A9aVx8UB6I5g, tp_del);
TM__NTBSFVABaCX7j6t0zZIyng_0[60].typ = (&NTIdestructor__32w2ZypAyMWuajvi2Jt79cg_);
TM__NTBSFVABaCX7j6t0zZIyng_0[60].name = "tp_del";
TM__NTBSFVABaCX7j6t0zZIyng_5_48[45] = &TM__NTBSFVABaCX7j6t0zZIyng_0[61];
TM__NTBSFVABaCX7j6t0zZIyng_0[61].kind = 1;
TM__NTBSFVABaCX7j6t0zZIyng_0[61].offset = offsetof(tyObject_PyTypeObject3Obj__cRsC9bGvH9bX6A9aVx8UB6I5g, tp_version_tag);
TM__NTBSFVABaCX7j6t0zZIyng_0[61].typ = (&NTIcuint__EfDYb5NOiMBijiUDCmXqPw_);
TM__NTBSFVABaCX7j6t0zZIyng_0[61].name = "tp_version_tag";
TM__NTBSFVABaCX7j6t0zZIyng_5_48[46] = &TM__NTBSFVABaCX7j6t0zZIyng_0[62];
TM__NTBSFVABaCX7j6t0zZIyng_0[62].kind = 1;
TM__NTBSFVABaCX7j6t0zZIyng_0[62].offset = offsetof(tyObject_PyTypeObject3Obj__cRsC9bGvH9bX6A9aVx8UB6I5g, tp_finalize);
TM__NTBSFVABaCX7j6t0zZIyng_0[62].typ = (&NTIdestructor__32w2ZypAyMWuajvi2Jt79cg_);
TM__NTBSFVABaCX7j6t0zZIyng_0[62].name = "tp_finalize";
TM__NTBSFVABaCX7j6t0zZIyng_5_48[47] = &TM__NTBSFVABaCX7j6t0zZIyng_0[63];
NTIvectorcallfunc__3hYcL7bVv9cte9aw9aoXtthhA_.size = sizeof(tyProc__3hYcL7bVv9cte9aw9aoXtthhA);
NTIvectorcallfunc__3hYcL7bVv9cte9aw9aoXtthhA_.align = NIM_ALIGNOF(tyProc__3hYcL7bVv9cte9aw9aoXtthhA);
NTIvectorcallfunc__3hYcL7bVv9cte9aw9aoXtthhA_.kind = 25;
NTIvectorcallfunc__3hYcL7bVv9cte9aw9aoXtthhA_.base = 0;
NTIvectorcallfunc__3hYcL7bVv9cte9aw9aoXtthhA_.flags = 3;
TM__NTBSFVABaCX7j6t0zZIyng_0[63].kind = 1;
TM__NTBSFVABaCX7j6t0zZIyng_0[63].offset = offsetof(tyObject_PyTypeObject3Obj__cRsC9bGvH9bX6A9aVx8UB6I5g, tp_vectorcall);
TM__NTBSFVABaCX7j6t0zZIyng_0[63].typ = (&NTIvectorcallfunc__3hYcL7bVv9cte9aw9aoXtthhA_);
TM__NTBSFVABaCX7j6t0zZIyng_0[63].name = "tp_vectorcall";
TM__NTBSFVABaCX7j6t0zZIyng_0[15].len = 48; TM__NTBSFVABaCX7j6t0zZIyng_0[15].kind = 2; TM__NTBSFVABaCX7j6t0zZIyng_0[15].sons = &TM__NTBSFVABaCX7j6t0zZIyng_5_48[0];
NTIpytypeobject51obj__cRsC9bGvH9bX6A9aVx8UB6I5g_.node = &TM__NTBSFVABaCX7j6t0zZIyng_0[15];
NTIpytypeobject__dgEY47TsFEQv355iEJP9bPA_.size = sizeof(tyObject_PyTypeObject3Obj__cRsC9bGvH9bX6A9aVx8UB6I5g*);
NTIpytypeobject__dgEY47TsFEQv355iEJP9bPA_.align = NIM_ALIGNOF(tyObject_PyTypeObject3Obj__cRsC9bGvH9bX6A9aVx8UB6I5g*);
NTIpytypeobject__dgEY47TsFEQv355iEJP9bPA_.kind = 21;
NTIpytypeobject__dgEY47TsFEQv355iEJP9bPA_.base = (&NTIpytypeobject51obj__cRsC9bGvH9bX6A9aVx8UB6I5g_);
NTIpytypeobject__dgEY47TsFEQv355iEJP9bPA_.flags = 3;
}

